==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/SnmpUI/src/com/clustercontrol/snmp/composite/SnmpListComposite.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.snmp.composite;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Table;

import com.clustercontrol.composite.CommonTableViewer;
import com.clustercontrol.monitor.run.bean.MonitorTypeConstant;
import com.clustercontrol.snmp.action.GetSnmp;
import com.clustercontrol.snmp.action.GetSnmpListTableDefine;
import com.clustercontrol.snmp.bean.SnmpTabelDefine;

/**
 * SNMPƻݥåȥ饹Ǥ
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class SnmpListComposite extends Composite {

    // ----- instance ե ----- //

    /** ơ֥ӥ塼 */
    private CommonTableViewer tableViewer = null;

    // ----- 󥹥ȥ饯 ----- //

    /**
     * 󥹥󥹤֤ޤ
     * 
     * @param parent
     *            ƤΥݥå
     * @param style
     *            
     */
    public SnmpListComposite(Composite parent, int style) {
        super(parent, style);

        this.initialize();
    }

    // ----- instance ᥽å ----- //

    /**
     * ݥåȤۤޤ
     */
    private void initialize() {
        GridLayout layout = new GridLayout(1, true);
        this.setLayout(layout);
        layout.marginHeight = 0;
        layout.marginWidth = 0;

        Table table = new Table(this, SWT.MULTI | SWT.H_SCROLL | SWT.V_SCROLL
                | SWT.FULL_SELECTION);
        table.setHeaderVisible(true);
        table.setLinesVisible(true);

        GridData gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;
        gridData.grabExcessHorizontalSpace = true;
        gridData.grabExcessVerticalSpace = true;
        table.setLayoutData(gridData);

        // ơ֥ӥ塼κ
        this.tableViewer = new CommonTableViewer(table);
        this.tableViewer.createTableColumn(GetSnmpListTableDefine.get(),
        		SnmpTabelDefine.SORT_COLUMN_INDEX,
        		SnmpTabelDefine.SORT_ORDER);

        gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;

        this.update();
    }

    /**
     * tableViewer֤ޤ
     * 
     * @return tableViewer
     */
    public CommonTableViewer getTableViewer() {
        return this.tableViewer;
    }

    /**
     * ݥåȤ򹹿ޤ
     * <p>
     * 
     */
    public void update() {
        // ǡ
    	ArrayList list = new GetSnmp().getSnmpList();
    	 
        // ơ֥빹
        this.tableViewer.setInput(list);
    }
    
    
    /**
     * 򤵤줿ԤδƻID
     * 
     * @return 
     */
    public ArrayList<SelectItem> getSelectionData() {
    	
    	ArrayList<SelectItem> data = new ArrayList<SelectItem>();
    	
    	//򤵤줿ƥ
    	StructuredSelection selection = 
    		(StructuredSelection)tableViewer.getSelection();
    	List list = (List)selection.toList();
    	
    	if (list != null) {
    		for(int index = 0; index < list.size(); index++){
    			
    			ArrayList info = (ArrayList)list.get(index);
    			if (info != null && info.size() > 0) {
    				SelectItem item = new SelectItem();
    				item.setMonitorId((String)info.get(SnmpTabelDefine.MONITOR_ID));
    				item.setMonitorType(MonitorTypeConstant.stringToType((String)info.get(SnmpTabelDefine.MONITOR_TYPE)));
    				data.add(item);
    			}
    		}
    	}
    	
    	return data;
    }
    
    /**
     * 򥢥ƥ९饹
     * 
     * @version 2.1.0
     * @since 2.1.0
     */
    public class SelectItem {

    	/** ƻID */
    	protected String monitorId;
    	
    	/** ƻܼ */
    	protected int monitorType = MonitorTypeConstant.TYPE_NUMERIC;

    	public String getMonitorId() {
    		return monitorId;
    	}

    	public void setMonitorId(String monitorId) {
    		this.monitorId = monitorId;
    	}

    	public int getMonitorType() {
    		return monitorType;
    	}

    	public void setMonitorType(int monitorType) {
    		this.monitorType = monitorType;
    	}
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/SnmpUI/src/com/clustercontrol/snmp/composite/SnmpListComposite.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.snmp.composite;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Table;

import com.clustercontrol.composite.CommonTableViewer;
import com.clustercontrol.monitor.run.bean.MonitorTypeConstant;
import com.clustercontrol.snmp.action.GetSnmp;
import com.clustercontrol.snmp.action.GetSnmpListTableDefine;
import com.clustercontrol.snmp.bean.SnmpTabelDefine;

/**
 * SNMP監視一覧コンポジットクラスです。
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class SnmpListComposite extends Composite {

    // ----- instance フィールド ----- //

    /** テーブルビューア */
    private CommonTableViewer tableViewer = null;

    // ----- コンストラクタ ----- //

    /**
     * インスタンスを返します。
     * 
     * @param parent
     *            親のコンポジット
     * @param style
     *            スタイル
     */
    public SnmpListComposite(Composite parent, int style) {
        super(parent, style);

        this.initialize();
    }

    // ----- instance メソッド ----- //

    /**
     * コンポジットを生成・構築します。
     */
    private void initialize() {
        GridLayout layout = new GridLayout(1, true);
        this.setLayout(layout);
        layout.marginHeight = 0;
        layout.marginWidth = 0;

        Table table = new Table(this, SWT.MULTI | SWT.H_SCROLL | SWT.V_SCROLL
                | SWT.FULL_SELECTION);
        table.setHeaderVisible(true);
        table.setLinesVisible(true);

        GridData gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;
        gridData.grabExcessHorizontalSpace = true;
        gridData.grabExcessVerticalSpace = true;
        table.setLayoutData(gridData);

        // テーブルビューアの作成
        this.tableViewer = new CommonTableViewer(table);
        this.tableViewer.createTableColumn(GetSnmpListTableDefine.get(),
        		SnmpTabelDefine.SORT_COLUMN_INDEX,
        		SnmpTabelDefine.SORT_ORDER);

        gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;

        this.update();
    }

    /**
     * tableViewerを返します。
     * 
     * @return tableViewer
     */
    public CommonTableViewer getTableViewer() {
        return this.tableViewer;
    }

    /**
     * コンポジットを更新します。
     * <p>
     * 
     */
    public void update() {
        // データ取得
    	ArrayList list = new GetSnmp().getSnmpList();
    	 
        // テーブル更新
        this.tableViewer.setInput(list);
    }
    
    
    /**
     * 選択された行の監視項目IDを取得する
     * 
     * @return 
     */
    public ArrayList<SelectItem> getSelectionData() {
    	
    	ArrayList<SelectItem> data = new ArrayList<SelectItem>();
    	
    	//選択されたアイテムを取得
    	StructuredSelection selection = 
    		(StructuredSelection)tableViewer.getSelection();
    	List list = (List)selection.toList();
    	
    	if (list != null) {
    		for(int index = 0; index < list.size(); index++){
    			
    			ArrayList info = (ArrayList)list.get(index);
    			if (info != null && info.size() > 0) {
    				SelectItem item = new SelectItem();
    				item.setMonitorId((String)info.get(SnmpTabelDefine.MONITOR_ID));
    				item.setMonitorType(MonitorTypeConstant.stringToType((String)info.get(SnmpTabelDefine.MONITOR_TYPE)));
    				data.add(item);
    			}
    		}
    	}
    	
    	return data;
    }
    
    /**
     * 選択アイテムクラス
     * 
     * @version 2.1.0
     * @since 2.1.0
     */
    public class SelectItem {

    	/** 監視項目ID */
    	protected String monitorId;
    	
    	/** 監視項目種別 */
    	protected int monitorType = MonitorTypeConstant.TYPE_NUMERIC;

    	public String getMonitorId() {
    		return monitorId;
    	}

    	public void setMonitorId(String monitorId) {
    		this.monitorId = monitorId;
    	}

    	public int getMonitorType() {
    		return monitorType;
    	}

    	public void setMonitorType(int monitorType) {
    		this.monitorType = monitorType;
    	}
    }
}
